package com.qizhen.healsphere.repository.postgresql;

import com.qizhen.healsphere.repository.neo4j.param.UpdatePropertyParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.stereotype.Repository;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Repository
public class PropertyRepository {

    @Autowired
    private JdbcTemplate jdbcTemplate;

    private final RowMapper<Map<String, Object>> propertyMapper = (rs, rowNum) -> {
        Map<String, Object> map = new HashMap<>();
        map.put("id", rs.getLong("id"));
        map.put("category", rs.getInt("category"));
        map.put("ref_id", rs.getLong("ref_id"));
        map.put("prop_name", rs.getString("prop_name"));
        map.put("prop_value", rs.getString("prop_value"));
        map.put("prop_title", rs.getString("prop_title"));
        map.put("type", rs.getShort("type"));
        return map;
    };

    /**
     * 新增实体属性
     * @param category
     * @param nodeId
     * @param properties
     * @return 属性map
     */
    public Map<String, Object> createProperty(String category, Long nodeId, Map<String, Object> properties) {
        String sql = "INSERT INTO kg_props (category, ref_id, prop_name, prop_value, prop_title, type) VALUES (?, ?, ?, ?, ?, ?) RETURNING *";
        List<Map<String, Object>> results = jdbcTemplate.query(
            sql,
            propertyMapper,
            0, // category默认为0
            nodeId,
            properties.keySet().stream().findFirst().get(),
            properties.values().stream().findFirst().get(),
            properties.keySet().stream().findFirst().get(),
            1
        );
        return results.isEmpty() ? new HashMap<>() : results.get(0);
    }

    /**
     * 删除实体属性
     * @param category
     * @param nodeId
     * @param propertyName
     * @return 删除的属性map
     */
    public Map<String, Object> deleteProperty(String category, Long nodeId, String propertyName) {
        String deleteSql = "DELETE FROM kg_props WHERE ref_id = ? AND prop_name = ?";
        jdbcTemplate.update(deleteSql, nodeId, propertyName);

        String selectSql = "SELECT * FROM kg_props WHERE ref_id = ? AND prop_name = ?";
        List<Map<String, Object>> properties = jdbcTemplate.query(selectSql, propertyMapper, nodeId, propertyName);
        
        return properties.isEmpty() ? new HashMap<>() : properties.get(0);
    }

    /**
     * 更新实体属性
     * @param updatePropertyParam
     * @return 更新后的属性map
     */
    public Map<String, Object> updateProperty(UpdatePropertyParam updatePropertyParam) {
        String sql = "UPDATE kg_props SET prop_name = ?, prop_value = ? WHERE ref_id = ? AND prop_name = ? RETURNING *";
        List<Map<String, Object>> results = jdbcTemplate.query(
            sql,
            propertyMapper,
            updatePropertyParam.getNewPropertyName(),
            updatePropertyParam.getNewPropertyValue(),
            updatePropertyParam.getNodeId(),
            updatePropertyParam.getOldPropertyName()
        );
        return results.isEmpty() ? new HashMap<>() : results.get(0);
    }
}