package com.qizhen.healsphere.util;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;

import java.lang.reflect.Field;
import java.util.*;

public class ObjectToMapConverter {

    /**
     * 将对象转换为Map<String, List<Object>>格式
     * @param obj 需要转换的对象
     * @return 转换后的Map
     */
    public static JSONArray convertToMap(Object obj) {
        JSONArray jsonArray = new JSONArray();
        if (obj == null) {
            return jsonArray;
        }

        Class<?> clazz = obj.getClass();
        for (Field field : clazz.getDeclaredFields()) {
            field.setAccessible(true);
            try {
                Object value = field.get(obj);
                List<Object> valueList = new ArrayList<>();
                if (value != null) {
                    if (value instanceof Map) {
                        // 处理 Map 类型的字段
                        Map<?, ?> mapValue = (Map<?, ?>) value;
                        for (Map.Entry<?, ?> entry : mapValue.entrySet()) {
                            JSONObject mapEntry = new JSONObject();
                            mapEntry.put("key", entry.getKey());
                            mapEntry.put("value", Arrays.asList(entry.getValue()));
                            valueList.add(mapEntry);
                        }
                    } else if (value instanceof Collection) {
                        // 处理 Collection 类型的字段
                        valueList.addAll((Collection<?>) value);
                    } else {
                        // 处理普通字段
                        valueList.add(value);
                    }
                    JSONObject jsonObject = new JSONObject();
                    jsonObject.put("key", field.getName());
                    jsonObject.put("value", valueList);
                    jsonArray.add(jsonObject);
                }
            } catch (IllegalAccessException e) {
                e.printStackTrace();
            }
        }
        return jsonArray;
    }

    public static void main(String[] args) {
        // 示例对象
        ExampleObject exampleObject = new ExampleObject();
        exampleObject.setName("Test");
        exampleObject.setHobbies(Arrays.asList("Reading", "Swimming"));
        Map<String, Object> properties = new HashMap<>();
        properties.put("描述", "英俊潇洒");
        exampleObject.setProperties(properties);
        System.out.println(JSON.toJSONString(exampleObject));
        // 转换为Map
        System.out.println(JSON.toJSONString(convertToMap(exampleObject)));
    }
}

class ExampleObject {
    private String name;
    private List<String> hobbies;

    public Map<String, Object> getProperties() {
        return properties;
    }

    public void setProperties(Map<String, Object> properties) {
        this.properties = properties;
    }

    private Map<String, Object> properties;

    // Getters and Setters
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public List<String> getHobbies() {
        return hobbies;
    }

    public void setHobbies(List<String> hobbies) {
        this.hobbies = hobbies;
    }
}